@@ -3,7 +3,7 @@ package Acme::CPANAuthors::Japanese;
 use strict;
 use warnings;
 
-our $VERSION = '0.101014';
+our $VERSION = '0.111011';
 
 use Acme::CPANAuthors::Register (
     AERDAN    => 'Kiyoshi Aman',
@@ -71,16 +71,19 @@ use Acme::CPANAuthors::Register (
     IKEBE     => 'IKEBE Tomohiro',
     IKEGAMI   => 'ikegami',
     IKUTA     => 'Masahito Ikuta',
+    IIZUKA    => 'Nao Iizuka',
     INA       => 'INABA Hitoshi',
     ISHIGAKI  => 'Kenichi Ishigaki',
     ISOYA     => 'Ryohei Isoya',
     ISSM      => 'IWATA, Susumu',
     ITWARRIOR => 'Hitoshi Amano',
+    JAMADAM   => 'Sugama Keita',
     JIRO      => 'Jiro Nishiguchi',
     JKONDO    => 'Junya Kondo',
     JUNICHIRO => 'Junichiro Tobe',
     KAMIPO    => 'Ryuta Kamizono',
     KAMO      => 'Yoshikazu Kamoshida',
+    KARUPA    => 'Kenta Sato',
     KAWABATA  => 'KAWABATA Kazumichi',
     KAWASAKI  => 'Kawasaki Yusuke',
     KAZEBURO  => 'Masahiro Nagano',
@@ -106,6 +109,7 @@ use Acme::CPANAuthors::Register (
     KTAT      => 'Kato Atsushi',
     KUBOTA    => 'Tomohiro KUBOTA',
     KUMA      => 'KUMAGAI Kentaro',
+    KUMAKATSU => 'katsuki ookuma',
     KUNIYOSHI => 'Kuniyoshi Kouji',
     KURIHARA  => 'Yoshiki KURIHARA',
     KURIYAMA  => 'Jun Kuriyama',
@@ -117,6 +121,7 @@ use Acme::CPANAuthors::Register (
     KYORO     => 'Kyosuke INOUE',
     KZFM      => 'Kazufumi Ohkawa',
     KZTOMITA  => 'Kazuyoshi Tomita',
+    KZYS      => 'Kato Kazuyoshi',
     LUSHE     => 'Masatoshi Mizuno',
     LYOKATO   => 'Lyo Kato',
     MAHITO    => 'Hogelist',
@@ -161,19 +166,23 @@ use Acme::CPANAuthors::Register (
     NOZZZZZ   => 'Tetsunari Nozaki',
     NTSUTSUMI => 'Naoya Tsutsumi',
     NYARLA    => 'Naoki Okamura',
+    OKAMUUU   => 'Masao Okamura',
     OINUME    => 'Kazuhiro Oinuma',
     OISHI     => 'Eisuke Oishi',
+    ONISHI    => 'Yasuhiro Onishi',
     OUEST     => 'Daisuke NISHISAKA',
     OYAMA     => 'Hiroyuki OYAMA',
     OZAWA     => 'OZAWA Sakuro',
     PAINA     => 'SATO Taisuke',
     PEN       => 'Abe Masahiro',
     PIA       => 'Michiya Honda',
+    PIROLIX   => 'Hiroyuki UENISHI',
     POCKET    => 'Masato Sogame',
     POPPEN    => 'Shinsuke Matsui',
     QUEEN     => 'Yasuhiro Miyazaki',
     RINTARO   => 'Rintaro Ishizaki',
     RIYWO     => 'Ryosuke IWANAGA',
+    ROZARY    => 'Syunsuke Fujishiro',
     RYOCHIN   => 'Okamoto RYO',
     SADAHIRO  => 'SADAHIRO Tomoyuki',
     SASAO     => 'SASAO Takahiro',
@@ -183,6 +192,8 @@ use Acme::CPANAuthors::Register (
     SEKIMURA  => 'Masayoshi Sekimura',
     SERA      => 'Kazuhiro Sera',
     SEYN      => 'Yasushi Nakajima',
+    SHARADA   => 'Seiji Harada',
+    SHIBAZAKI => 'Yuki Shibazaki',
     SHIBUYA   => 'Kazuhiro Shibuya',
     SHIGETA   => 'Takatsugu Shigeta',
     SHIGIO    => 'Shigio Yamaguchi',
@@ -196,9 +207,12 @@ use Acme::CPANAuthors::Register (
     SKUBOTA   => 'Satoshi KUBOTA',
     SNGJOKEN  => 'Shingo Kikugawa',
     SONGMU    => 'Masayuki Matsuki',
+    SSEI      => 'Shinichiro Sei',
     SUGMAK    => 'Makoto Sugiyama',
     SUZUKI    => 'Yuji Suzuki',
     SYNCLOVER => 'Naoya Sato',
+    SZARATE   => 'Santiago Zarate',
+    TAGOMORIS => 'Satoshi Tagomori',
     TAIY      => 'Taisuke Yamada',
     TAKASHI   => 'Takashi Saeki',
     TAKAYUKI  => 'Takayuki Ikeda',
@@ -221,6 +235,8 @@ use Acme::CPANAuthors::Register (
     TKURITA   => 'Tetsuro KURITA',
     TMAESAKA  => 'Toru Maesaka',
     TOCIYUKI  => 'MIZUTANI, Tociyuki',
+    TODA      => 'Yusuke Toda',
+    TOKUBASS  => 'Kouji Tominaga',
     TOKUHIROM => 'MATSUNO Tokuhiro',
     TOMITA    => 'Naoki Tomita',
     TOMYHERO  => 'Tomohiro Teranishi',
@@ -237,7 +253,9 @@ use Acme::CPANAuthors::Register (
     TYANO     => 'Tatsuhiro YANO',
     TYPESTER  => 'Daisuke Murase',
     UMEMOTO   => 'Hajimu Umemoto',
+    UNLEARNED => 'Takashi Uesugi',
     USUALOMA  => 'Taku Amano',
+    WATA      => 'Kouji Watanabe',
     WATANABE  => 'WATANABE Hirofumi',
     WOREMACX  => 'Wore Macx',
     XAICRON   => 'Yuji Shimada',
@@ -250,6 +268,7 @@ use Acme::CPANAuthors::Register (
     YAPPO     => 'Kazuhiro Osawa',
     YASU      => 'Yasushi Saito',
     YASUHIRO  => 'Yasuhiro Onishi',
+    YAYOHEI   => 'Yohei Yamamoto',
     YIBE      => 'Yuki Ibe',
     YOSHIDA   => 'Hironori Yoshida',
     YOSHIMI   => 'Keiji Yoshimi',
